@@ -1,5 +1,5 @@
 package experimentals;
-our $VERSION = '0.017';
+our $VERSION = '0.018';
 
 use 5.010;
 use strict;
@@ -40,10 +40,16 @@ sub import {
     # Always enable all available features...
     feature->import(keys %FEATURES);
 
+    # Turn on utf8 if the feature requires it...
+    if ($FEATURES{ extra_paired_delimiters }) {
+        require utf8;
+        utf8->import();
+    }
+
     # Are we reporting???
     my $reporting = grep { defined $_ && lc($_) eq '-report' } @_;
 
-    # If not reporting, disable all warnings avout experimental features...
+    # If not reporting, disable all warnings about experimental features...
     if (!$reporting) {
         warnings->unimport(keys %WARNINGS);
     }
@@ -81,7 +87,7 @@ experimentals - Experimental features made even easier
 
 =head1 VERSION
 
-This document describes experimentals version 0.017
+This document describes experimentals version 0.018
 
 
 =head1 SYNOPSIS
@@ -99,22 +105,20 @@ This document describes experimentals version 0.017
 C<use experimental> is a life-saver under modern Perls,
 but if you want to be truly modern Perl hacker you need something like:
 
-    use v5.22;
+    use v5.26;
     use experimental qw(
-            fc          postderef     current_sub
-            say         regex_sets    unicode_eval
-            state       array_base    postderef_qq
-            switch      smartmatch    lexical_subs
-            bitwise     signatures    lexical_topic
-            evalbytes   refaliasing   unicode_strings
-            autoderef
+            fc        evalbytes     current_sub
+            say       array_base    unicode_eval
+            state     smartmatch    postderef_qq
+            switch    signatures    declared_refs
+            bitwise   refaliasing   unicode_strings
     );
 
 which is uncomfortably verbose.
 
 This module reduces that to:
 
-    use v5.22;
+    use v5.26;
     use experimentals;
 
 
@@ -143,7 +147,7 @@ So you can turn on every modern feature, except one or two you don't
 trust, like so:
 
     use experimentals;
-    no experimental 'lexical_topic', 'smartmatch', 'array_base';
+    no experimental 'smartmatch', 'array_base';
 
 Likewise, in some inner scope you can lexically disable all experimental features, except
 the few you actually need, with:
